# -*- encoding: utf-8 -*-

import json

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from .helpers import get_compose, get_fixture

from compose_utils import get_listing


class ListingTest(unittest.TestCase):

    def test_get_listing(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        with open(get_fixture("full-listing.json")) as fh:
            expected = json.load(fh)

        listing = get_listing(compose.rpms)

        self.assertEqual(listing, expected)

    def test_get_listing_filter_but_keep_all_variants(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        with open(get_fixture("full-listing.json")) as fh:
            expected = json.load(fh)

        listing = get_listing(compose.rpms, variants=["Client", "Server"])

        self.assertEqual(listing, expected)

    def test_get_listing_filter_but_keep_all_arches(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        with open(get_fixture("full-listing.json")) as fh:
            expected = json.load(fh)

        listing = get_listing(compose.rpms, arches=["x86_64", "i386", "s390x"])

        self.assertEqual(listing, expected)

    def test_get_listing_filter_trees(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        with open(get_fixture("listing-server-x86_64.json")) as fh:
            expected = json.load(fh)

        listing = get_listing(compose.rpms, variants=["Server"], arches=["x86_64"])

        self.assertEqual(listing, expected)

    def test_get_listing_filter_pkg_arch(self):
        compose = get_compose("DP-1.0-20160315.t.0")
        with open(get_fixture("listing-multilib.json")) as fh:
            expected = json.load(fh)

        listing = get_listing(compose.rpms, pkg_arches=["i686"], arches=["x86_64"])

        self.assertEqual(listing, expected)
